from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RdiscCls:
	"""Rdisc commands group definition. 13 total commands, 13 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rdisc", core, parent)

	@property
	def cperiod(self):
		"""cperiod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cperiod'):
			from .Cperiod import CperiodCls
			self._cperiod = CperiodCls(self._core, self._cmd_group)
		return self._cperiod

	@property
	def n1Pdsch(self):
		"""n1Pdsch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n1Pdsch'):
			from .N1Pdsch import N1PdschCls
			self._n1Pdsch = N1PdschCls(self._core, self._cmd_group)
		return self._n1Pdsch

	@property
	def n2Pdsch(self):
		"""n2Pdsch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n2Pdsch'):
			from .N2Pdsch import N2PdschCls
			self._n2Pdsch = N2PdschCls(self._core, self._cmd_group)
		return self._n2Pdsch

	@property
	def n3Pdsch(self):
		"""n3Pdsch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n3Pdsch'):
			from .N3Pdsch import N3PdschCls
			self._n3Pdsch = N3PdschCls(self._core, self._cmd_group)
		return self._n3Pdsch

	@property
	def nrepetitions(self):
		"""nrepetitions commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nrepetitions'):
			from .Nrepetitions import NrepetitionsCls
			self._nrepetitions = NrepetitionsCls(self._core, self._cmd_group)
		return self._nrepetitions

	@property
	def nretrans(self):
		"""nretrans commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nretrans'):
			from .Nretrans import NretransCls
			self._nretrans = NretransCls(self._core, self._cmd_group)
		return self._nretrans

	@property
	def offsetInd(self):
		"""offsetInd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offsetInd'):
			from .OffsetInd import OffsetIndCls
			self._offsetInd = OffsetIndCls(self._core, self._cmd_group)
		return self._offsetInd

	@property
	def prbNumber(self):
		"""prbNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prbNumber'):
			from .PrbNumber import PrbNumberCls
			self._prbNumber = PrbNumberCls(self._core, self._cmd_group)
		return self._prbNumber

	@property
	def prbStart(self):
		"""prbStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prbStart'):
			from .PrbStart import PrbStartCls
			self._prbStart = PrbStartCls(self._core, self._cmd_group)
		return self._prbStart

	@property
	def prend(self):
		"""prend commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prend'):
			from .Prend import PrendCls
			self._prend = PrendCls(self._core, self._cmd_group)
		return self._prend

	@property
	def prIndex(self):
		"""prIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prIndex'):
			from .PrIndex import PrIndexCls
			self._prIndex = PrIndexCls(self._core, self._cmd_group)
		return self._prIndex

	@property
	def sfbmp(self):
		"""sfbmp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfbmp'):
			from .Sfbmp import SfbmpCls
			self._sfbmp = SfbmpCls(self._core, self._cmd_group)
		return self._sfbmp

	@property
	def sfIndex(self):
		"""sfIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfIndex'):
			from .SfIndex import SfIndexCls
			self._sfIndex = SfIndexCls(self._core, self._cmd_group)
		return self._sfIndex

	def clone(self) -> 'RdiscCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RdiscCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScrptCls:
	"""Scrpt commands group definition. 5 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scrpt", core, parent)

	@property
	def discard(self):
		"""discard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_discard'):
			from .Discard import DiscardCls
			self._discard = DiscardCls(self._core, self._cmd_group)
		return self._discard

	def get_arg(self) -> str:
		"""SCPI: SYSTem:SCRPt:ARG \n
		Snippet: value: str = driver.system.scrpt.get_arg() \n
		No command help available \n
			:return: arguments: No help available
		"""
		response = self._core.io.query_str('SYSTem:SCRPt:ARG?')
		return trim_str_response(response)

	def set_arg(self, arguments: str) -> None:
		"""SCPI: SYSTem:SCRPt:ARG \n
		Snippet: driver.system.scrpt.set_arg(arguments = 'abc') \n
		No command help available \n
			:param arguments: No help available
		"""
		param = Conversions.value_to_quoted_str(arguments)
		self._core.io.write(f'SYSTem:SCRPt:ARG {param}')

	def get_cmd(self) -> str:
		"""SCPI: SYSTem:SCRPt:CMD \n
		Snippet: value: str = driver.system.scrpt.get_cmd() \n
		No command help available \n
			:return: cmd_file: No help available
		"""
		response = self._core.io.query_str('SYSTem:SCRPt:CMD?')
		return trim_str_response(response)

	def set_cmd(self, cmd_file: str) -> None:
		"""SCPI: SYSTem:SCRPt:CMD \n
		Snippet: driver.system.scrpt.set_cmd(cmd_file = 'abc') \n
		No command help available \n
			:param cmd_file: No help available
		"""
		param = Conversions.value_to_quoted_str(cmd_file)
		self._core.io.write(f'SYSTem:SCRPt:CMD {param}')

	def get_data(self) -> str:
		"""SCPI: SYSTem:SCRPt:DATA \n
		Snippet: value: str = driver.system.scrpt.get_data() \n
		No command help available \n
			:return: data_file: No help available
		"""
		response = self._core.io.query_str('SYSTem:SCRPt:DATA?')
		return trim_str_response(response)

	def set_data(self, data_file: str) -> None:
		"""SCPI: SYSTem:SCRPt:DATA \n
		Snippet: driver.system.scrpt.set_data(data_file = 'abc') \n
		No command help available \n
			:param data_file: No help available
		"""
		param = Conversions.value_to_quoted_str(data_file)
		self._core.io.write(f'SYSTem:SCRPt:DATA {param}')

	def run(self) -> None:
		"""SCPI: SYSTem:SCRPt:RUN \n
		Snippet: driver.system.scrpt.run() \n
		No command help available \n
		"""
		self._core.io.write(f'SYSTem:SCRPt:RUN')

	def run_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:SCRPt:RUN \n
		Snippet: driver.system.scrpt.run_with_opc() \n
		No command help available \n
		Same as run, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:SCRPt:RUN', opc_timeout_ms)

	def clone(self) -> 'ScrptCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScrptCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PathCls:
	"""Path commands group definition. 11 total commands, 10 Subgroups, 0 group commands
	Repeated Capability: Path, default value after init: Path.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_path_get', 'repcap_path_set', repcap.Path.Nr1)

	def repcap_path_set(self, path: repcap.Path) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Path.Default
		Default value after init: Path.Nr1"""
		self._cmd_group.set_repcap_enum_value(path)

	def repcap_path_get(self) -> repcap.Path:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def adelay(self):
		"""adelay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adelay'):
			from .Adelay import AdelayCls
			self._adelay = AdelayCls(self._core, self._cmd_group)
		return self._adelay

	@property
	def bdelay(self):
		"""bdelay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdelay'):
			from .Bdelay import BdelayCls
			self._bdelay = BdelayCls(self._core, self._cmd_group)
		return self._bdelay

	@property
	def cphase(self):
		"""cphase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cphase'):
			from .Cphase import CphaseCls
			self._cphase = CphaseCls(self._core, self._cmd_group)
		return self._cphase

	@property
	def fdoppler(self):
		"""fdoppler commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdoppler'):
			from .Fdoppler import FdopplerCls
			self._fdoppler = FdopplerCls(self._core, self._cmd_group)
		return self._fdoppler

	@property
	def fratio(self):
		"""fratio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fratio'):
			from .Fratio import FratioCls
			self._fratio = FratioCls(self._core, self._cmd_group)
		return self._fratio

	@property
	def loss(self):
		"""loss commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_loss'):
			from .Loss import LossCls
			self._loss = LossCls(self._core, self._cmd_group)
		return self._loss

	@property
	def profile(self):
		"""profile commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_profile'):
			from .Profile import ProfileCls
			self._profile = ProfileCls(self._core, self._cmd_group)
		return self._profile

	@property
	def rdelay(self):
		"""rdelay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rdelay'):
			from .Rdelay import RdelayCls
			self._rdelay = RdelayCls(self._core, self._cmd_group)
		return self._rdelay

	@property
	def speed(self):
		"""speed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_speed'):
			from .Speed import SpeedCls
			self._speed = SpeedCls(self._core, self._cmd_group)
		return self._speed

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'PathCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PathCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhysBitsCls:
	"""PhysBits commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("physBits", core, parent)

	def get(self, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ALLoc<CH0>:PHYSbits \n
		Snippet: value: int = driver.source.bb.v5G.downlink.subf.alloc.physBits.get(subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Queries the size of the selected allocation in bits and considering the subcarriers that are used for other signals or
		channels with higher priority. For a user 1...4, the total number of physical bits is the sum of the 'Physical Bits' of
		all single allocations that belong to the same user in the subframe. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: physical_bits: integer Range: 0 to 105600"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PHYSbits?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	def get_qcomponent(self) -> float:
		"""SCPI: TEST:BB:GENerator:PHASe:Q \n
		Snippet: value: float = driver.test.bb.generator.phase.get_qcomponent() \n
		No command help available \n
			:return: test_gen_phase_q: No help available
		"""
		response = self._core.io.query_str('TEST:BB:GENerator:PHASe:Q?')
		return Conversions.str_to_float(response)

	def set_qcomponent(self, test_gen_phase_q: float) -> None:
		"""SCPI: TEST:BB:GENerator:PHASe:Q \n
		Snippet: driver.test.bb.generator.phase.set_qcomponent(test_gen_phase_q = 1.0) \n
		No command help available \n
			:param test_gen_phase_q: No help available
		"""
		param = Conversions.decimal_value_to_str(test_gen_phase_q)
		self._core.io.write(f'TEST:BB:GENerator:PHASe:Q {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrectionCls:
	"""Correction commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correction", core, parent)

	def get_file(self) -> str:
		"""SCPI: SOURce<HW>:BEXTension:CORRection:FILE \n
		Snippet: value: str = driver.source.bextension.correction.get_file() \n
		No command help available \n
			:return: correction_file: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BEXTension:CORRection:FILE?')
		return trim_str_response(response)

	def set_file(self, correction_file: str) -> None:
		"""SCPI: SOURce<HW>:BEXTension:CORRection:FILE \n
		Snippet: driver.source.bextension.correction.set_file(correction_file = 'abc') \n
		No command help available \n
			:param correction_file: No help available
		"""
		param = Conversions.value_to_quoted_str(correction_file)
		self._core.io.write(f'SOURce<HwInstance>:BEXTension:CORRection:FILE {param}')

	def get_state(self) -> bool:
		"""SCPI: SOURce<HW>:BEXTension:CORRection:STATe \n
		Snippet: value: bool = driver.source.bextension.correction.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BEXTension:CORRection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: SOURce<HW>:BEXTension:CORRection:STATe \n
		Snippet: driver.source.bextension.correction.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BEXTension:CORRection:STATe {param}')



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrsCls:
	"""Srs commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("srs", core, parent)

	@property
	def bd23(self):
		"""bd23 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bd23'):
			from .Bd23 import Bd23Cls
			self._bd23 = Bd23Cls(self._core, self._cmd_group)
		return self._bd23

	@property
	def gtype(self):
		"""gtype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gtype'):
			from .Gtype import GtypeCls
			self._gtype = GtypeCls(self._core, self._cmd_group)
		return self._gtype

	@property
	def nb26(self):
		"""nb26 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nb26'):
			from .Nb26 import Nb26Cls
			self._nb26 = Nb26Cls(self._core, self._cmd_group)
		return self._nb26

	@property
	def nscg(self):
		"""nscg commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nscg'):
			from .Nscg import NscgCls
			self._nscg = NscgCls(self._core, self._cmd_group)
		return self._nscg

	def clone(self) -> 'SrsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SrsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InitializationCls:
	"""Initialization commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("initialization", core, parent)

	@property
	def predefined(self):
		"""predefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_predefined'):
			from .Predefined import PredefinedCls
			self._predefined = PredefinedCls(self._core, self._cmd_group)
		return self._predefined

	def get_catalog(self) -> List[str]:
		"""SCPI: SCONfiguration:EXTernal:REMote:INITialization:CATalog \n
		Snippet: value: List[str] = driver.sconfiguration.external.remote.initialization.get_catalog() \n
		Queries the names of the existing initialization files in the default directory. Per default, the instrument saves
		user-defined files in the /var/user/ directory. Use the command method RsSmw.MassMemory.currentDirectory to change the
		default directory to the currently used one. Only files with extension *.iec are listed. \n
			:return: rf_rem_ctrl_scpi_init_cat_name_user: No help available
		"""
		response = self._core.io.query_str('SCONfiguration:EXTernal:REMote:INITialization:CATalog?')
		return Conversions.str_to_str_list(response)

	def clone(self) -> 'InitializationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InitializationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ChannelCls:
	"""Channel commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("channel", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def stream(self):
		"""stream commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_stream'):
			from .Stream import StreamCls
			self._stream = StreamCls(self._core, self._cmd_group)
		return self._stream

	def clone(self) -> 'ChannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ChannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DsSimulationCls:
	"""DsSimulation commands group definition. 84 total commands, 4 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dsSimulation", core, parent)

	@property
	def create(self):
		"""create commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_create'):
			from .Create import CreateCls
			self._create = CreateCls(self._core, self._cmd_group)
		return self._create

	@property
	def shiptoship(self):
		"""shiptoship commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_shiptoship'):
			from .Shiptoship import ShiptoshipCls
			self._shiptoship = ShiptoshipCls(self._core, self._cmd_group)
		return self._shiptoship

	@property
	def towerToAir(self):
		"""towerToAir commands group. 7 Sub-classes, 4 commands."""
		if not hasattr(self, '_towerToAir'):
			from .TowerToAir import TowerToAirCls
			self._towerToAir = TowerToAirCls(self._core, self._cmd_group)
		return self._towerToAir

	@property
	def user(self):
		"""user commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_user'):
			from .User import UserCls
			self._user = UserCls(self._core, self._cmd_group)
		return self._user

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:CATalog \n
		Snippet: value: List[str] = driver.source.fsimulator.dsSimulation.get_catalog() \n
		No command help available \n
			:return: scenario_files: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:CATalog?')
		return Conversions.str_to_str_list(response)

	# noinspection PyTypeChecker
	def get_cformat(self) -> enums.FadDssRealAppr:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:CFORmat \n
		Snippet: value: enums.FadDssRealAppr = driver.source.fsimulator.dsSimulation.get_cformat() \n
		No command help available \n
			:return: coor_format: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:CFORmat?')
		return Conversions.str_to_scalar_enum(response, enums.FadDssRealAppr)

	def set_cformat(self, coor_format: enums.FadDssRealAppr) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:CFORmat \n
		Snippet: driver.source.fsimulator.dsSimulation.set_cformat(coor_format = enums.FadDssRealAppr.DECimal) \n
		No command help available \n
			:param coor_format: No help available
		"""
		param = Conversions.enum_scalar_to_str(coor_format, enums.FadDssRealAppr)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:CFORmat {param}')

	def get_load(self) -> str:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:LOAD \n
		Snippet: value: str = driver.source.fsimulator.dsSimulation.get_load() \n
		No command help available \n
			:return: scenario_file: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:LOAD?')
		return trim_str_response(response)

	def set_load(self, scenario_file: str) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:LOAD \n
		Snippet: driver.source.fsimulator.dsSimulation.set_load(scenario_file = 'abc') \n
		No command help available \n
			:param scenario_file: No help available
		"""
		param = Conversions.value_to_quoted_str(scenario_file)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:LOAD {param}')

	def get_save(self) -> str:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:SAVE \n
		Snippet: value: str = driver.source.fsimulator.dsSimulation.get_save() \n
		No command help available \n
			:return: scenario_file: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:SAVE?')
		return trim_str_response(response)

	def set_save(self, scenario_file: str) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:SAVE \n
		Snippet: driver.source.fsimulator.dsSimulation.set_save(scenario_file = 'abc') \n
		No command help available \n
			:param scenario_file: No help available
		"""
		param = Conversions.value_to_quoted_str(scenario_file)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:SAVE {param}')

	# noinspection PyTypeChecker
	def get_scenario(self) -> enums.FadDssScen:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:SCENario \n
		Snippet: value: enums.FadDssScen = driver.source.fsimulator.dsSimulation.get_scenario() \n
		No command help available \n
			:return: scenario: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:SCENario?')
		return Conversions.str_to_scalar_enum(response, enums.FadDssScen)

	def set_scenario(self, scenario: enums.FadDssScen) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:SCENario \n
		Snippet: driver.source.fsimulator.dsSimulation.set_scenario(scenario = enums.FadDssScen.SHIPtoship) \n
		No command help available \n
			:param scenario: No help available
		"""
		param = Conversions.enum_scalar_to_str(scenario, enums.FadDssScen)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:SCENario {param}')

	def clone(self) -> 'DsSimulationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DsSimulationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllocCls:
	"""Alloc commands group definition. 33 total commands, 19 Subgroups, 0 group commands
	Repeated Capability: AllocationNull, default value after init: AllocationNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alloc", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_allocationNull_get', 'repcap_allocationNull_set', repcap.AllocationNull.Nr0)

	def repcap_allocationNull_set(self, allocationNull: repcap.AllocationNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AllocationNull.Default
		Default value after init: AllocationNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(allocationNull)

	def repcap_allocationNull_get(self) -> repcap.AllocationNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ciqFile(self):
		"""ciqFile commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ciqFile'):
			from .CiqFile import CiqFileCls
			self._ciqFile = CiqFileCls(self._core, self._cmd_group)
		return self._ciqFile

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import ConflictCls
			self._conflict = ConflictCls(self._core, self._cmd_group)
		return self._conflict

	@property
	def conPoint(self):
		"""conPoint commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_conPoint'):
			from .ConPoint import ConPointCls
			self._conPoint = ConPointCls(self._core, self._cmd_group)
		return self._conPoint

	@property
	def content(self):
		"""content commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_content'):
			from .Content import ContentCls
			self._content = ContentCls(self._core, self._cmd_group)
		return self._content

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def moor(self):
		"""moor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_moor'):
			from .Moor import MoorCls
			self._moor = MoorCls(self._core, self._cmd_group)
		return self._moor

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def physBits(self):
		"""physBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_physBits'):
			from .PhysBits import PhysBitsCls
			self._physBits = PhysBitsCls(self._core, self._cmd_group)
		return self._physBits

	@property
	def pwr(self):
		"""pwr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pwr'):
			from .Pwr import PwrCls
			self._pwr = PwrCls(self._core, self._cmd_group)
		return self._pwr

	@property
	def scma(self):
		"""scma commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_scma'):
			from .Scma import ScmaCls
			self._scma = ScmaCls(self._core, self._cmd_group)
		return self._scma

	@property
	def scno(self):
		"""scno commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scno'):
			from .Scno import ScnoCls
			self._scno = ScnoCls(self._core, self._cmd_group)
		return self._scno

	@property
	def scOffset(self):
		"""scOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scOffset'):
			from .ScOffset import ScOffsetCls
			self._scOffset = ScOffsetCls(self._core, self._cmd_group)
		return self._scOffset

	@property
	def splt(self):
		"""splt commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_splt'):
			from .Splt import SpltCls
			self._splt = SpltCls(self._core, self._cmd_group)
		return self._splt

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def syno(self):
		"""syno commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_syno'):
			from .Syno import SynoCls
			self._syno = SynoCls(self._core, self._cmd_group)
		return self._syno

	@property
	def syOffset(self):
		"""syOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_syOffset'):
			from .SyOffset import SyOffsetCls
			self._syOffset = SyOffsetCls(self._core, self._cmd_group)
		return self._syOffset

	@property
	def zad(self):
		"""zad commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_zad'):
			from .Zad import ZadCls
			self._zad = ZadCls(self._core, self._cmd_group)
		return self._zad

	def clone(self) -> 'AllocCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AllocCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoordinatesCls:
	"""Coordinates commands group definition. 5 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coordinates", core, parent)

	@property
	def decimal(self):
		"""decimal commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_decimal'):
			from .Decimal import DecimalCls
			self._decimal = DecimalCls(self._core, self._cmd_group)
		return self._decimal

	@property
	def dms(self):
		"""dms commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_dms'):
			from .Dms import DmsCls
			self._dms = DmsCls(self._core, self._cmd_group)
		return self._dms

	# noinspection PyTypeChecker
	def get_rframe(self) -> enums.RefFrame:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GALileo:LOCation:COORdinates:RFRame \n
		Snippet: value: enums.RefFrame = driver.source.bb.gnss.adGeneration.galileo.location.coordinates.get_rframe() \n
		Sets the reference frame. \n
			:return: reference_frame: PZ90| WGS84
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GALileo:LOCation:COORdinates:RFRame?')
		return Conversions.str_to_scalar_enum(response, enums.RefFrame)

	def set_rframe(self, reference_frame: enums.RefFrame) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GALileo:LOCation:COORdinates:RFRame \n
		Snippet: driver.source.bb.gnss.adGeneration.galileo.location.coordinates.set_rframe(reference_frame = enums.RefFrame.PZ90) \n
		Sets the reference frame. \n
			:param reference_frame: PZ90| WGS84
		"""
		param = Conversions.enum_scalar_to_str(reference_frame, enums.RefFrame)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GALileo:LOCation:COORdinates:RFRame {param}')

	def clone(self) -> 'CoordinatesCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CoordinatesCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: OUTPut<HW>:USER<CH>:TRIGger:[IMMediate] \n
		Snippet: driver.output.user.trigger.immediate.set(userIx = repcap.UserIx.Default) \n
		Generates a short pulse signal and outputs it at the USER connector. This signal can serve as a common external trigger
		signal for triggering of several R&S SMW, see Example 'Triggering several R&S SMW instruments simultaneously'. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'OUTPut<HwInstance>:USER{userIx_cmd_val}:TRIGger:IMMediate')

	def set_with_opc(self, userIx=repcap.UserIx.Default, opc_timeout_ms: int = -1) -> None:
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		"""SCPI: OUTPut<HW>:USER<CH>:TRIGger:[IMMediate] \n
		Snippet: driver.output.user.trigger.immediate.set_with_opc(userIx = repcap.UserIx.Default) \n
		Generates a short pulse signal and outputs it at the USER connector. This signal can serve as a common external trigger
		signal for triggering of several R&S SMW, see Example 'Triggering several R&S SMW instruments simultaneously'. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'OUTPut<HwInstance>:USER{userIx_cmd_val}:TRIGger:IMMediate', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QcksetCls:
	"""Qckset commands group definition. 31 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("qckset", core, parent)

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import ApplyCls
			self._apply = ApplyCls(self._core, self._cmd_group)
		return self._apply

	@property
	def discard(self):
		"""discard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_discard'):
			from .Discard import DiscardCls
			self._discard = DiscardCls(self._core, self._cmd_group)
		return self._discard

	@property
	def frmFormat(self):
		"""frmFormat commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_frmFormat'):
			from .FrmFormat import FrmFormatCls
			self._frmFormat = FrmFormatCls(self._core, self._cmd_group)
		return self._frmFormat

	@property
	def general(self):
		"""general commands group. 2 Sub-classes, 9 commands."""
		if not hasattr(self, '_general'):
			from .General import GeneralCls
			self._general = GeneralCls(self._core, self._cmd_group)
		return self._general

	def set_state(self, qck_set_state: enums.QuickSetStateAll) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:STATe \n
		Snippet: driver.source.bb.nr5G.qckset.set_state(qck_set_state = enums.QuickSetStateAll.DIS) \n
		No command help available \n
			:param qck_set_state: No help available
		"""
		param = Conversions.enum_scalar_to_str(qck_set_state, enums.QuickSetStateAll)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:STATe {param}')

	def clone(self) -> 'QcksetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = QcksetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BitFrameCls:
	"""BitFrame commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bitFrame", core, parent)

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:CCODing:BITFrame \n
		Snippet: value: int = driver.source.bb.c2K.bstation.cgroup.coffset.ccoding.bitFrame.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Queries the number of input bits per frame for the channel coder. This value is only available for channel coding modes
		'Complete' and 'Without Interleaving' (SOURce:BB:C2K:BST<n>:CGRoup<n>:COFFset<n>:CCODing:MODE COMP | NOIN) .
		For the traffic channels, this value is specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: bit_frame: integer Range: 16 to 20712"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:CCODing:BITFrame?')
		return Conversions.str_to_int(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxSchemeCls:
	"""TxScheme commands group definition. 12 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("txScheme", core, parent)

	@property
	def apcsirs(self):
		"""apcsirs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apcsirs'):
			from .Apcsirs import ApcsirsCls
			self._apcsirs = ApcsirsCls(self._core, self._cmd_group)
		return self._apcsirs

	@property
	def cbmd(self):
		"""cbmd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbmd'):
			from .Cbmd import CbmdCls
			self._cbmd = CbmdCls(self._core, self._cmd_group)
		return self._cbmd

	@property
	def cbType(self):
		"""cbType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbType'):
			from .CbType import CbTypeCls
			self._cbType = CbTypeCls(self._core, self._cmd_group)
		return self._cbType

	@property
	def cdmData(self):
		"""cdmData commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdmData'):
			from .CdmData import CdmDataCls
			self._cdmData = CdmDataCls(self._core, self._cmd_group)
		return self._cdmData

	@property
	def intervp(self):
		"""intervp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_intervp'):
			from .Intervp import IntervpCls
			self._intervp = IntervpCls(self._core, self._cmd_group)
		return self._intervp

	@property
	def nlayers(self):
		"""nlayers commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nlayers'):
			from .Nlayers import NlayersCls
			self._nlayers = NlayersCls(self._core, self._cmd_group)
		return self._nlayers

	@property
	def pcn1(self):
		"""pcn1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcn1'):
			from .Pcn1 import Pcn1Cls
			self._pcn1 = Pcn1Cls(self._core, self._cmd_group)
		return self._pcn1

	@property
	def pcn2(self):
		"""pcn2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcn2'):
			from .Pcn2 import Pcn2Cls
			self._pcn2 = Pcn2Cls(self._core, self._cmd_group)
		return self._pcn2

	@property
	def spcb(self):
		"""spcb commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_spcb'):
			from .Spcb import SpcbCls
			self._spcb = SpcbCls(self._core, self._cmd_group)
		return self._spcb

	def clone(self) -> 'TxSchemeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TxSchemeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	@property
	def hdr(self):
		"""hdr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hdr'):
			from .Hdr import HdrCls
			self._hdr = HdrCls(self._core, self._cmd_group)
		return self._hdr

	def get_variation(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:SRATe:VARiation \n
		Snippet: value: float = driver.source.bb.btooth.symbolRate.get_variation() \n
		Sets the symbol rate. \n
			:return: variation: float Range: 4E2 to 15E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:SRATe:VARiation?')
		return Conversions.str_to_float(response)

	def set_variation(self, variation: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:SRATe:VARiation \n
		Snippet: driver.source.bb.btooth.symbolRate.set_variation(variation = 1.0) \n
		Sets the symbol rate. \n
			:param variation: float Range: 4E2 to 15E6
		"""
		param = Conversions.decimal_value_to_str(variation)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:SRATe:VARiation {param}')

	def clone(self) -> 'SymbolRateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SymbolRateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisplayCls:
	"""Display commands group definition. 17 total commands, 6 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("display", core, parent)

	@property
	def annotation(self):
		"""annotation commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_annotation'):
			from .Annotation import AnnotationCls
			self._annotation = AnnotationCls(self._core, self._cmd_group)
		return self._annotation

	@property
	def dialog(self):
		"""dialog commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_dialog'):
			from .Dialog import DialogCls
			self._dialog = DialogCls(self._core, self._cmd_group)
		return self._dialog

	@property
	def psave(self):
		"""psave commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_psave'):
			from .Psave import PsaveCls
			self._psave = PsaveCls(self._core, self._cmd_group)
		return self._psave

	@property
	def touch(self):
		"""touch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_touch'):
			from .Touch import TouchCls
			self._touch = TouchCls(self._core, self._cmd_group)
		return self._touch

	@property
	def ukey(self):
		"""ukey commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_ukey'):
			from .Ukey import UkeyCls
			self._ukey = UkeyCls(self._core, self._cmd_group)
		return self._ukey

	@property
	def update(self):
		"""update commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_update'):
			from .Update import UpdateCls
			self._update = UpdateCls(self._core, self._cmd_group)
		return self._update

	def set_focus_object(self, obj_name: str) -> None:
		"""SCPI: DISPlay:FOCusobject \n
		Snippet: driver.display.set_focus_object(obj_name = 'abc') \n
		No command help available \n
			:param obj_name: No help available
		"""
		param = Conversions.value_to_quoted_str(obj_name)
		self._core.io.write(f'DISPlay:FOCusobject {param}')

	def set_message(self, message: str) -> None:
		"""SCPI: DISPlay:MESSage \n
		Snippet: driver.display.set_message(message = 'abc') \n
		No command help available \n
			:param message: No help available
		"""
		param = Conversions.value_to_quoted_str(message)
		self._core.io.write(f'DISPlay:MESSage {param}')

	def clone(self) -> 'DisplayCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DisplayCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtkCls:
	"""Rtk commands group definition. 30 total commands, 2 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rtk", core, parent)

	@property
	def base(self):
		"""base commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_base'):
			from .Base import BaseCls
			self._base = BaseCls(self._core, self._cmd_group)
		return self._base

	@property
	def bstation(self):
		"""bstation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bstation'):
			from .Bstation import BstationCls
			self._bstation = BstationCls(self._core, self._cmd_group)
		return self._bstation

	def get_password(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:PASSword \n
		Snippet: value: str = driver.source.bb.gnss.rtk.get_password() \n
		Queries the password, that belongs to the RTCM user name. \n
			:return: password: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RTK:PASSword?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_port(self) -> enums.RtkPort:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:PORT \n
		Snippet: value: enums.RtkPort = driver.source.bb.gnss.rtk.get_port() \n
		Sets the port number of the LAN connection. \n
			:return: port_number: 2101| 4022| 50000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RTK:PORT?')
		return Conversions.str_to_scalar_enum(response, enums.RtkPort)

	def set_port(self, port_number: enums.RtkPort) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:PORT \n
		Snippet: driver.source.bb.gnss.rtk.set_port(port_number = enums.RtkPort._2101) \n
		Sets the port number of the LAN connection. \n
			:param port_number: 2101| 4022| 50000
		"""
		param = Conversions.enum_scalar_to_str(port_number, enums.RtkPort)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RTK:PORT {param}')

	# noinspection PyTypeChecker
	def get_protocol(self) -> enums.RtkProtocol:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:PROTocol \n
		Snippet: value: enums.RtkProtocol = driver.source.bb.gnss.rtk.get_protocol() \n
		Queries the protocol for transmitting RTK data. \n
			:return: protocol: RTCM NTRIP/RTCM 3.3 protocol
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RTK:PROTocol?')
		return Conversions.str_to_scalar_enum(response, enums.RtkProtocol)

	def set_protocol(self, protocol: enums.RtkProtocol) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:PROTocol \n
		Snippet: driver.source.bb.gnss.rtk.set_protocol(protocol = enums.RtkProtocol.RTCM) \n
		Queries the protocol for transmitting RTK data. \n
			:param protocol: RTCM NTRIP/RTCM 3.3 protocol
		"""
		param = Conversions.enum_scalar_to_str(protocol, enums.RtkProtocol)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RTK:PROTocol {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.rtk.get_state() \n
		Activates real-time kinematics simulation. \n
			:return: rtk_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RTK:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, rtk_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:STATe \n
		Snippet: driver.source.bb.gnss.rtk.set_state(rtk_state = False) \n
		Activates real-time kinematics simulation. \n
			:param rtk_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(rtk_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RTK:STATe {param}')

	def get_user(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:USER \n
		Snippet: value: str = driver.source.bb.gnss.rtk.get_user() \n
		Queries the user ID, that is the RTCM user name. \n
			:return: user_id: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RTK:USER?')
		return trim_str_response(response)

	def clone(self) -> 'RtkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RtkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BwCls:
	"""Bw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bw", core, parent)

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default) -> enums.OneWebUlChannelBandwidth:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:CA:CELL<CH0>:BW \n
		Snippet: value: enums.OneWebUlChannelBandwidth = driver.source.bb.oneweb.uplink.ca.cell.bw.get(cellNull = repcap.CellNull.Default) \n
		Queries the bandwidth of the corresponding component carrier. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: ulca_bw: BW20_00"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:UL:CA:CELL{cellNull_cmd_val}:BW?')
		return Conversions.str_to_scalar_enum(response, enums.OneWebUlChannelBandwidth)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SyInfoCls:
	"""SyInfo commands group definition. 5 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("syInfo", core, parent)

	@property
	def hacbook(self):
		"""hacbook commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hacbook'):
			from .Hacbook import HacbookCls
			self._hacbook = HacbookCls(self._core, self._cmd_group)
		return self._hacbook

	@property
	def hacr(self):
		"""hacr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hacr'):
			from .Hacr import HacrCls
			self._hacr = HacrCls(self._core, self._cmd_group)
		return self._hacr

	@property
	def indSize(self):
		"""indSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_indSize'):
			from .IndSize import IndSizeCls
			self._indSize = IndSizeCls(self._core, self._cmd_group)
		return self._indSize

	@property
	def is02(self):
		"""is02 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_is02'):
			from .Is02 import Is02Cls
			self._is02 = Is02Cls(self._core, self._cmd_group)
		return self._is02

	@property
	def sul(self):
		"""sul commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sul'):
			from .Sul import SulCls
			self._sul = SulCls(self._core, self._cmd_group)
		return self._sul

	def clone(self) -> 'SyInfoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SyInfoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SeedCls:
	"""Seed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("seed", core, parent)

	def set(self, seed: int, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:SEED \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.seed.set(seed = 1, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the seed for the random process deciding between the four options (see 'Randomly varying modulation and number of
		codes (Type 3i) settings') . \n
			:param seed: integer Range: 0 to 65535
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.decimal_value_to_str(seed)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:SEED {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:SEED \n
		Snippet: value: int = driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.seed.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the seed for the random process deciding between the four options (see 'Randomly varying modulation and number of
		codes (Type 3i) settings') . \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: seed: integer Range: 0 to 65535"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:SEED?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NiotCls:
	"""Niot commands group definition. 6 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("niot", core, parent)

	@property
	def cfg(self):
		"""cfg commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_cfg'):
			from .Cfg import CfgCls
			self._cfg = CfgCls(self._core, self._cmd_group)
		return self._cfg

	# noinspection PyTypeChecker
	def get_pfmt(self) -> enums.EutraPracNbiotPreambleFormat:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:NIOT:PFMT \n
		Snippet: value: enums.EutraPracNbiotPreambleFormat = driver.source.bb.eutra.uplink.prach.niot.get_pfmt() \n
		Select the preamble format. \n
			:return: preamble_format: F0| F1 | 0| 1 | F2| F0A| F1A 0|1 backward compatibility; use F0|F1 instead.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:UL:PRACh:NIOT:PFMT?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPracNbiotPreambleFormat)

	def set_pfmt(self, preamble_format: enums.EutraPracNbiotPreambleFormat) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:NIOT:PFMT \n
		Snippet: driver.source.bb.eutra.uplink.prach.niot.set_pfmt(preamble_format = enums.EutraPracNbiotPreambleFormat._0) \n
		Select the preamble format. \n
			:param preamble_format: F0| F1 | 0| 1 | F2| F0A| F1A 0|1 backward compatibility; use F0|F1 instead.
		"""
		param = Conversions.enum_scalar_to_str(preamble_format, enums.EutraPracNbiotPreambleFormat)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:NIOT:PFMT {param}')

	def clone(self) -> 'NiotCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NiotCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SetCls:
	"""Set commands group definition. 6 total commands, 6 Subgroups, 0 group commands
	Repeated Capability: SetItem, default value after init: SetItem.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("set", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_setItem_get', 'repcap_setItem_set', repcap.SetItem.Nr1)

	def repcap_setItem_set(self, setItem: repcap.SetItem) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SetItem.Default
		Default value after init: SetItem.Nr1"""
		self._cmd_group.set_repcap_enum_value(setItem)

	def repcap_setItem_get(self) -> repcap.SetItem:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def nid(self):
		"""nid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nid'):
			from .Nid import NidCls
			self._nid = NidCls(self._core, self._cmd_group)
		return self._nid

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def prbs(self):
		"""prbs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prbs'):
			from .Prbs import PrbsCls
			self._prbs = PrbsCls(self._core, self._cmd_group)
		return self._prbs

	@property
	def rba(self):
		"""rba commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rba'):
			from .Rba import RbaCls
			self._rba = RbaCls(self._core, self._cmd_group)
		return self._rba

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def ttyp(self):
		"""ttyp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttyp'):
			from .Ttyp import TtypCls
			self._ttyp = TtypCls(self._core, self._cmd_group)
		return self._ttyp

	def clone(self) -> 'SetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:SCRambling:STATe \n
		Snippet: driver.source.bb.eutra.uplink.ue.cell.pusch.scrambling.state.set(state = False, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Enables/disables scrambling for all PUSCH allocations of the corresponding UE. \n
			:param state: 1| ON| 0| OFF
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.bool_to_str(state)
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:SCRambling:STATe {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:SCRambling:STATe \n
		Snippet: value: bool = driver.source.bb.eutra.uplink.ue.cell.pusch.scrambling.state.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Enables/disables scrambling for all PUSCH allocations of the corresponding UE. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: state: 1| ON| 0| OFF"""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:SCRambling:STATe?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class L2BandCls:
	"""L2Band commands group definition. 19 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("l2Band", core, parent)

	@property
	def e6Prs(self):
		"""e6Prs commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_e6Prs'):
			from .E6Prs import E6PrsCls
			self._e6Prs = E6PrsCls(self._core, self._cmd_group)
		return self._e6Prs

	@property
	def e6S(self):
		"""e6S commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_e6S'):
			from .E6S import E6SCls
			self._e6S = E6SCls(self._core, self._cmd_group)
		return self._e6S

	def clone(self) -> 'L2BandCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = L2BandCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MtiaCls:
	"""Mtia commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mtia", core, parent)

	def set(self, nprs_muting_info_a: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:MTIA \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.mtia.set(nprs_muting_info_a = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1) \n
		Sets the nprs-MutingInfoA/nprs-MutingInfoB parameter, required if muting is used for the NPRS part A (and Part B)
		configurations. \n
			:param nprs_muting_info_a: numeric '1' indicates that the NPRS is transmitted in the corresponding occasion; a '0' indicates a muted NPRS.
			:param bitcount: integer Sets the length of the periodically repeating NPRS bit sequence in number of NPRS position occurrences. Allowed are the following values: 2, 4, 8 or 16 Range: 2 to 16
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('nprs_muting_info_a', nprs_muting_info_a, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:MTIA {param}'.rstrip())

	# noinspection PyTypeChecker
	class MtiaStruct(StructBase):
		"""Response structure. Fields: \n
			- Nprs_Muting_Info_A: List[str]: No parameter help available
			- Bitcount: int: integer Sets the length of the periodically repeating NPRS bit sequence in number of NPRS position occurrences. Allowed are the following values: 2, 4, 8 or 16 Range: 2 to 16"""
		__meta_args_list = [
			ArgStruct('Nprs_Muting_Info_A', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Nprs_Muting_Info_A: List[str] = None
			self.Bitcount: int = None

	def get(self) -> MtiaStruct:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:MTIA \n
		Snippet: value: MtiaStruct = driver.source.bb.eutra.downlink.niot.nprs.mtia.get() \n
		Sets the nprs-MutingInfoA/nprs-MutingInfoB parameter, required if muting is used for the NPRS part A (and Part B)
		configurations. \n
			:return: structure: for return value, see the help for MtiaStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:MTIA?', self.__class__.MtiaStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbCls:
	"""Bb commands group definition. 25 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bb", core, parent)

	@property
	def bnc(self):
		"""bnc commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_bnc'):
			from .Bnc import BncCls
			self._bnc = BncCls(self._core, self._cmd_group)
		return self._bnc

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def generator(self):
		"""generator commands group. 5 Sub-classes, 3 commands."""
		if not hasattr(self, '_generator'):
			from .Generator import GeneratorCls
			self._generator = GeneratorCls(self._core, self._cmd_group)
		return self._generator

	def get_connection(self) -> bool:
		"""SCPI: TEST:BB:CONNection \n
		Snippet: value: bool = driver.test.bb.get_connection() \n
		No command help available \n
			:return: connection: No help available
		"""
		response = self._core.io.query_str('TEST:BB:CONNection?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'BbCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BbCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, length: int, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:HSDPA:HARQ:LENGth \n
		Snippet: driver.source.bb.tdscdma.up.cell.enh.dch.hsdpa.harq.length.set(length = 1, cell = repcap.Cell.Default) \n
		Sets the number of HARQ processes. This value determines the distribution of the payload in the subframes and depends on
		the inter-TTI distance. A minimum of three HARQ Processes are required to achieve continuous data transmission. \n
			:param length: integer Range: 1 to 8
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(length)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:HSDPA:HARQ:LENGth {param}')

	def get(self, cell=repcap.Cell.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:HSDPA:HARQ:LENGth \n
		Snippet: value: int = driver.source.bb.tdscdma.up.cell.enh.dch.hsdpa.harq.length.get(cell = repcap.Cell.Default) \n
		Sets the number of HARQ processes. This value determines the distribution of the payload in the subframes and depends on
		the inter-TTI distance. A minimum of three HARQ Processes are required to achieve continuous data transmission. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: length: integer Range: 1 to 8"""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:HSDPA:HARQ:LENGth?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EratioCls:
	"""Eratio commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eratio", core, parent)

	def set(self, state: bool, twoStreams=repcap.TwoStreams.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:STReam<DI>:ERATio \n
		Snippet: driver.source.bb.esequencer.stream.eratio.set(state = False, twoStreams = repcap.TwoStreams.Default) \n
		No command help available \n
			:param state: No help available
			:param twoStreams: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
		"""
		param = Conversions.bool_to_str(state)
		twoStreams_cmd_val = self._cmd_group.get_repcap_cmd_value(twoStreams, repcap.TwoStreams)
		self._core.io.write(f'SOURce<HwInstance>:BB:ESEQuencer:STReam{twoStreams_cmd_val}:ERATio {param}')

	def get(self, twoStreams=repcap.TwoStreams.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:STReam<DI>:ERATio \n
		Snippet: value: bool = driver.source.bb.esequencer.stream.eratio.get(twoStreams = repcap.TwoStreams.Default) \n
		No command help available \n
			:param twoStreams: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:return: state: No help available"""
		twoStreams_cmd_val = self._cmd_group.get_repcap_cmd_value(twoStreams, repcap.TwoStreams)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ESEQuencer:STReam{twoStreams_cmd_val}:ERATio?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DetectCls:
	"""Detect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("detect", core, parent)

	def get(self, iqConnector=repcap.IqConnector.Default) -> str:
		"""SCPI: SCONfiguration:EXTernal:BBMM<CH>:REMote:DETect \n
		Snippet: value: str = driver.sconfiguration.external.bbmm.remote.detect.get(iqConnector = repcap.IqConnector.Default) \n
		Searches for external instruments connected to the particular digital interfaces. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: detected_instr: string If the detection fails, the query returns 'None'."""
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SCONfiguration:EXTernal:BBMM{iqConnector_cmd_val}:REMote:DETect?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MagnCls:
	"""Magn commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("magn", core, parent)

	def set(self, cust_const_magn: float, allocationNull=repcap.AllocationNull.Default, constelationPointNull=repcap.ConstelationPointNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:ALLoc<CH0>:CONPoint<ST0>:MAGN \n
		Snippet: driver.source.bb.ofdm.alloc.conPoint.magn.set(cust_const_magn = 1.0, allocationNull = repcap.AllocationNull.Default, constelationPointNull = repcap.ConstelationPointNull.Default) \n
		Sets the magnitude of the constellation point of the selected allocation. The magnitude value applies for a cylindrical
		coordinate system. \n
			:param cust_const_magn: float Range: 0 to 100
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param constelationPointNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'ConPoint')
		"""
		param = Conversions.decimal_value_to_str(cust_const_magn)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		constelationPointNull_cmd_val = self._cmd_group.get_repcap_cmd_value(constelationPointNull, repcap.ConstelationPointNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:ALLoc{allocationNull_cmd_val}:CONPoint{constelationPointNull_cmd_val}:MAGN {param}')

	def get(self, allocationNull=repcap.AllocationNull.Default, constelationPointNull=repcap.ConstelationPointNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:OFDM:ALLoc<CH0>:CONPoint<ST0>:MAGN \n
		Snippet: value: float = driver.source.bb.ofdm.alloc.conPoint.magn.get(allocationNull = repcap.AllocationNull.Default, constelationPointNull = repcap.ConstelationPointNull.Default) \n
		Sets the magnitude of the constellation point of the selected allocation. The magnitude value applies for a cylindrical
		coordinate system. \n
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param constelationPointNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'ConPoint')
			:return: cust_const_magn: float Range: 0 to 100"""
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		constelationPointNull_cmd_val = self._cmd_group.get_repcap_cmd_value(constelationPointNull, repcap.ConstelationPointNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:OFDM:ALLoc{allocationNull_cmd_val}:CONPoint{constelationPointNull_cmd_val}:MAGN?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TagCls:
	"""Tag commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tag", core, parent)

	def get(self, tag_name: str) -> str:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:ETHernet:WAVeform:TAG \n
		Snippet: value: str = driver.source.bb.arbitrary.ethernet.waveform.tag.get(tag_name = 'abc') \n
		Queries waveform tags defined in the waveform file with extension *.wv. Query results are returned in a comma-separated
		list. Listed are pairs '<TagName>'<'<TagValue>'> for each tag. \n
			:param tag_name: string Name of the waveform tag.
			:return: tag_value: string Value of the waveform tag."""
		param = Conversions.value_to_quoted_str(tag_name)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ARBitrary:ETHernet:WAVeform:TAG? {param}')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def get(self, path=repcap.Path.Default) -> bool:
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:RCONnection:STATe \n
		Snippet: value: bool = driver.sconfiguration.external.rf.rconnection.state.get(path = repcap.Path.Default) \n
		Queries the status of the remote connection. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:return: state: 1| ON| 0| OFF"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SCONfiguration:EXTernal:RF{path_cmd_val}:RCONnection:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfConfigCls:
	"""SfConfig commands group definition. 17 total commands, 0 Subgroups, 17 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfConfig", core, parent)

	def get_csf_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:CSFLength \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_csf_length() \n
		Requires more than one super frame as set via the command SOURce1:sBB:DVB:DVBS|DVBX:SFBHconfig:NOSF.
		Queries the calculated super frame length in symbols. \n
			:return: calculated_sfl: integer Range: 8856 to 612540
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:CSFLength?')
		return Conversions.str_to_int(response)

	def get_cu_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:CULength \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_cu_length() \n
		Queries the capacity unit length. \n
			:return: cu_length: integer Range: 90 to 90
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:CULength?')
		return Conversions.str_to_int(response)

	def get_dsf(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:DSF \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_dsf() \n
		Queries the distance between super frame start and start of pilot field in the super frame. \n
			:return: pilot_filed_dis: integer Range: 1440 to 1440
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:DSF?')
		return Conversions.str_to_int(response)

	def get_ehf_size(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:EHFSize \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_ehf_size() \n
		Quereis the extended header filed (EHF) size. \n
			:return: ehf_size: integer Range: 504 to 504
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:EHFSize?')
		return Conversions.str_to_int(response)

	def get_npay(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:NPAY \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_npay() \n
		Sets the scrambling code number for the payload data scrambler. \n
			:return: npay: integer Range: 0 to 1048574
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:NPAY?')
		return Conversions.str_to_int(response)

	def set_npay(self, npay: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:NPAY \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_npay(npay = 1) \n
		Sets the scrambling code number for the payload data scrambler. \n
			:param npay: integer Range: 0 to 1048574
		"""
		param = Conversions.decimal_value_to_str(npay)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:NPAY {param}')

	def get_nref(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:NREF \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_nref() \n
		Sets the scrambling code number for the reference data scrambler. \n
			:return: nref: integer Range: 0 to 1048574
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:NREF?')
		return Conversions.str_to_int(response)

	def set_nref(self, nref: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:NREF \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_nref(nref = 1) \n
		Sets the scrambling code number for the reference data scrambler. \n
			:param nref: integer Range: 0 to 1048574
		"""
		param = Conversions.decimal_value_to_str(nref)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:NREF {param}')

	def get_plength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PLENgth \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_plength() \n
		Queries the postamble length. \n
			:return: postamble_length: integer Range: 90 to 900
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PLENgth?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_pli(self) -> enums.DvbS2Xsfpli:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PLI \n
		Snippet: value: enums.DvbS2Xsfpli = driver.source.bb.dvb.dvbx.sfConfig.get_pli() \n
		Selects the protection level indicator of the physical layer header. \n
			:return: pli: STD| ROB| VROB| HEFF STD Standard protection of physical layer header using BPSK with spreding factor 1. ROB Robust protection of physical layer header using BPSK with spreding factor 2. VROB Very robust protection of physical layer header using BPSK with spreding factor 5. HEFF High efficiency protection of physical layer header using QPSK with punctering. The selection applies only for 8PSK and higher MODCOD schemes refer to payload transfer.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PLI?')
		return Conversions.str_to_scalar_enum(response, enums.DvbS2Xsfpli)

	def set_pli(self, pli: enums.DvbS2Xsfpli) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PLI \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_pli(pli = enums.DvbS2Xsfpli.HEFF) \n
		Selects the protection level indicator of the physical layer header. \n
			:param pli: STD| ROB| VROB| HEFF STD Standard protection of physical layer header using BPSK with spreding factor 1. ROB Robust protection of physical layer header using BPSK with spreding factor 2. VROB Very robust protection of physical layer header using BPSK with spreding factor 5. HEFF High efficiency protection of physical layer header using QPSK with punctering. The selection applies only for 8PSK and higher MODCOD schemes refer to payload transfer.
		"""
		param = Conversions.enum_scalar_to_str(pli, enums.DvbS2Xsfpli)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PLI {param}')

	def get_psf(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PSF \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_psf() \n
		Queries the pilot field size. \n
			:return: pilot_field_size: integer Range: 36 to 36
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PSF?')
		return Conversions.str_to_int(response)

	def get_pstate(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PSTate \n
		Snippet: value: bool = driver.source.bb.dvb.dvbx.sfConfig.get_pstate() \n
		Sets the super frame pilot active. \n
			:return: sf_pilot_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PSTate?')
		return Conversions.str_to_bool(response)

	def set_pstate(self, sf_pilot_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PSTate \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_pstate(sf_pilot_state = False) \n
		Sets the super frame pilot active. \n
			:param sf_pilot_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(sf_pilot_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PSTate {param}')

	def get_pwh(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PWH \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_pwh() \n
		Sets the super frame pilot Walsh-Hadamard (WH) sequence set. \n
			:return: sf_pilot_wh: integer Range: 0 to 31
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PWH?')
		return Conversions.str_to_int(response)

	def set_pwh(self, sf_pilot_wh: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:PWH \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_pwh(sf_pilot_wh = 1) \n
		Sets the super frame pilot Walsh-Hadamard (WH) sequence set. \n
			:param sf_pilot_wh: integer Range: 0 to 31
		"""
		param = Conversions.decimal_value_to_str(sf_pilot_wh)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:PWH {param}')

	# noinspection PyTypeChecker
	def get_sffi(self) -> enums.DvbS2XsfFormat:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:SFFI \n
		Snippet: value: enums.DvbS2XsfFormat = driver.source.bb.dvb.dvbx.sfConfig.get_sffi() \n
		Sets the super frame format indicator to a value coinside with format 0 to format 7. \n
			:return: sffi: SFFI4| SFFI5| SFFI6| SFFI7 SFFI4 Requires deactivated beam hopping. Sets a fixed super frame length. SFFI5 Define a custom super frame length. SFFI6 to SFFI7 Requires activated beam hopping. Define a customized super frame length with activated beam hopping.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:SFFI?')
		return Conversions.str_to_scalar_enum(response, enums.DvbS2XsfFormat)

	def set_sffi(self, sffi: enums.DvbS2XsfFormat) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:SFFI \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_sffi(sffi = enums.DvbS2XsfFormat.SFFI0) \n
		Sets the super frame format indicator to a value coinside with format 0 to format 7. \n
			:param sffi: SFFI4| SFFI5| SFFI6| SFFI7 SFFI4 Requires deactivated beam hopping. Sets a fixed super frame length. SFFI5 Define a custom super frame length. SFFI6 to SFFI7 Requires activated beam hopping. Define a customized super frame length with activated beam hopping.
		"""
		param = Conversions.enum_scalar_to_str(sffi, enums.DvbS2XsfFormat)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:SFFI {param}')

	def get_sf_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:SFLength \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_sf_length() \n
		Sets the super frame length. SFFI 0 to 3 are not supported. For SFFI = 5 to 7, the command sets the superframe length.
		For SFFI = 4, this command is for query only. \n
			:return: sf_length: integer Range: 8856 to 612540
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:SFLength?')
		return Conversions.str_to_int(response)

	def set_sf_length(self, sf_length: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:SFLength \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_sf_length(sf_length = 1) \n
		Sets the super frame length. SFFI 0 to 3 are not supported. For SFFI = 5 to 7, the command sets the superframe length.
		For SFFI = 4, this command is for query only. \n
			:param sf_length: integer Range: 8856 to 612540
		"""
		param = Conversions.decimal_value_to_str(sf_length)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:SFLength {param}')

	def get_sosf(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:SOSF \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_sosf() \n
		Sets the start of super frame Walsh-Hadamard (WH) sequence. \n
			:return: sosf: integer Range: 0 to 255
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:SOSF?')
		return Conversions.str_to_int(response)

	def set_sosf(self, sosf: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:SOSF \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_sosf(sosf = 1) \n
		Sets the start of super frame Walsh-Hadamard (WH) sequence. \n
			:param sosf: integer Range: 0 to 255
		"""
		param = Conversions.decimal_value_to_str(sosf)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:SOSF {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:STATe \n
		Snippet: value: bool = driver.source.bb.dvb.dvbx.sfConfig.get_state() \n
		Activates the super frame. \n
			:return: sf_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, sf_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:STATe \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_state(sf_state = False) \n
		Activates the super frame. \n
			:param sf_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(sf_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:STATe {param}')

	def get_stwh(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:STWH \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_stwh() \n
		The super frame trailer (ST) extends the frame field in respect of the super frame header (SFH) with a Walsh-Hadamard
		(WH) sequence. \n
			:return: st: integer Range: 0 to 63
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:STWH?')
		return Conversions.str_to_int(response)

	def set_stwh(self, st: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:STWH \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_stwh(st = 1) \n
		The super frame trailer (ST) extends the frame field in respect of the super frame header (SFH) with a Walsh-Hadamard
		(WH) sequence. \n
			:param st: integer Range: 0 to 63
		"""
		param = Conversions.decimal_value_to_str(st)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:STWH {param}')

	def get_tsn(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:TSN \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.sfConfig.get_tsn() \n
		Sets the time slice number (TSN) . The TSN is identified in the wideband header. The TSN information determines which
		physical layer frames the receiver decodes and which frames the receiver discards. The dialog provides the setting of the
		time slice number (TSN) according to Annex M of . \n
			:return: tsn: integer Range: 0 to 255
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:TSN?')
		return Conversions.str_to_int(response)

	def set_tsn(self, tsn: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:SFConfig:TSN \n
		Snippet: driver.source.bb.dvb.dvbx.sfConfig.set_tsn(tsn = 1) \n
		Sets the time slice number (TSN) . The TSN is identified in the wideband header. The TSN information determines which
		physical layer frames the receiver decodes and which frames the receiver discards. The dialog provides the setting of the
		time slice number (TSN) according to Annex M of . \n
			:param tsn: integer Range: 0 to 255
		"""
		param = Conversions.decimal_value_to_str(tsn)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:SFConfig:TSN {param}')



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TdaNumCls:
	"""TdaNum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tdaNum", core, parent)

	def set(self, num_td_allocs: int, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, listIndexNull=repcap.ListIndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:TDML<GRP0>:TDANum \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.tdml.tdaNum.set(num_td_allocs = 1, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, listIndexNull = repcap.ListIndexNull.Default) \n
		Defines the number of multi time domain allocations in the selected time domain allocation list.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- [:SOURce<hw>]:BB:NR5G:UBWP:USER<us>:CELL<cc>:DL:BWP<bwp>:PDSCh:TDALists > 1 \n
			:param num_td_allocs: No help available
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param listIndexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tdml')
		"""
		param = Conversions.decimal_value_to_str(num_td_allocs)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		listIndexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(listIndexNull, repcap.ListIndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:TDML{listIndexNull_cmd_val}:TDANum {param}')

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, listIndexNull=repcap.ListIndexNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:TDML<GRP0>:TDANum \n
		Snippet: value: int = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.tdml.tdaNum.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, listIndexNull = repcap.ListIndexNull.Default) \n
		Defines the number of multi time domain allocations in the selected time domain allocation list.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- [:SOURce<hw>]:BB:NR5G:UBWP:USER<us>:CELL<cc>:DL:BWP<bwp>:PDSCh:TDALists > 1 \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param listIndexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tdml')
			:return: num_td_allocs: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		listIndexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(listIndexNull, repcap.ListIndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:TDML{listIndexNull_cmd_val}:TDANum?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FnumberCls:
	"""Fnumber commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fnumber", core, parent)

	def set(self, fnum: int, vdbTransmitter=repcap.VdbTransmitter.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:FNUMber \n
		Snippet: driver.source.bb.gbas.vdb.fnumber.set(fnum = 1, vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Sets the frequency number that the corresponding VDB is using. \n
			:param fnum: integer Range: -5 to 5
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
		"""
		param = Conversions.decimal_value_to_str(fnum)
		vdbTransmitter_cmd_val = self._cmd_group.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:FNUMber {param}')

	def get(self, vdbTransmitter=repcap.VdbTransmitter.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:FNUMber \n
		Snippet: value: int = driver.source.bb.gbas.vdb.fnumber.get(vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Sets the frequency number that the corresponding VDB is using. \n
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:return: fnum: integer Range: -5 to 5"""
		vdbTransmitter_cmd_val = self._cmd_group.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:FNUMber?')
		return Conversions.str_to_int(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import enums
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortCls:
	"""Port commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("port", core, parent)

	def set(self, max_nrof_ports: enums.MaxNrofPorts, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:PTRS:PORT \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.ptrs.port.set(max_nrof_ports = enums.MaxNrofPorts.P1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the maximum number of configured PTRS ports. \n
			:param max_nrof_ports: P1| P2
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
		"""
		param = Conversions.enum_scalar_to_str(max_nrof_ports, enums.MaxNrofPorts)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:PTRS:PORT {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> enums.MaxNrofPorts:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:PTRS:PORT \n
		Snippet: value: enums.MaxNrofPorts = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.ptrs.port.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the maximum number of configured PTRS ports. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: max_nrof_ports: P1| P2"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:PTRS:PORT?')
		return Conversions.str_to_scalar_enum(response, enums.MaxNrofPorts)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NprsCls:
	"""Nprs commands group definition. 12 total commands, 3 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nprs", core, parent)

	@property
	def bmp(self):
		"""bmp commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_bmp'):
			from .Bmp import BmpCls
			self._bmp = BmpCls(self._core, self._cmd_group)
		return self._bmp

	@property
	def mtia(self):
		"""mtia commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtia'):
			from .Mtia import MtiaCls
			self._mtia = MtiaCls(self._core, self._cmd_group)
		return self._mtia

	@property
	def mtib(self):
		"""mtib commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtib'):
			from .Mtib import MtibCls
			self._mtib = MtibCls(self._core, self._cmd_group)
		return self._mtib

	# noinspection PyTypeChecker
	def get_conf(self) -> enums.EutraNbiotNprsConfigType:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:CONF \n
		Snippet: value: enums.EutraNbiotNprsConfigType = driver.source.bb.eutra.downlink.niot.nprs.get_conf() \n
		Defines which type of NPRS is used. \n
			:return: nprs_para_cfg: PA_A| PA_B| PA_AB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:CONF?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotNprsConfigType)

	def set_conf(self, nprs_para_cfg: enums.EutraNbiotNprsConfigType) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:CONF \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_conf(nprs_para_cfg = enums.EutraNbiotNprsConfigType.PA_A) \n
		Defines which type of NPRS is used. \n
			:param nprs_para_cfg: PA_A| PA_B| PA_AB
		"""
		param = Conversions.enum_scalar_to_str(nprs_para_cfg, enums.EutraNbiotNprsConfigType)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:CONF {param}')

	def get_id(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:ID \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.nprs.get_id() \n
		Sets the NPRS-ID used for the generation of the NPRS. \n
			:return: nprs_id: Integer Range: 0 to 4095
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:ID?')
		return Conversions.str_to_int(response)

	def set_id(self, nprs_id: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:ID \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_id(nprs_id = 1) \n
		Sets the NPRS-ID used for the generation of the NPRS. \n
			:param nprs_id: Integer Range: 0 to 4095
		"""
		param = Conversions.decimal_value_to_str(nprs_id)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:ID {param}')

	# noinspection PyTypeChecker
	def get_period(self) -> enums.EutraNbiotNprsConfigbPeriod:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:PERiod \n
		Snippet: value: enums.EutraNbiotNprsConfigbPeriod = driver.source.bb.eutra.downlink.niot.nprs.get_period() \n
		For NPRS Part B configuration, sets the NPRS occasion period TNPRS. \n
			:return: nprs_period: PD_160| PD_320| PD_640| PD_1280
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:PERiod?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotNprsConfigbPeriod)

	def set_period(self, nprs_period: enums.EutraNbiotNprsConfigbPeriod) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:PERiod \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_period(nprs_period = enums.EutraNbiotNprsConfigbPeriod.PD_1280) \n
		For NPRS Part B configuration, sets the NPRS occasion period TNPRS. \n
			:param nprs_period: PD_160| PD_320| PD_640| PD_1280
		"""
		param = Conversions.enum_scalar_to_str(nprs_period, enums.EutraNbiotNprsConfigbPeriod)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:PERiod {param}')

	def get_pow(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:POW \n
		Snippet: value: float = driver.source.bb.eutra.downlink.niot.nprs.get_pow() \n
		Sets the power of the narrowband positioning reference signal (NPRS) . \n
			:return: nprs_power: float Range: -80 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:POW?')
		return Conversions.str_to_float(response)

	def set_pow(self, nprs_power: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:POW \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_pow(nprs_power = 1.0) \n
		Sets the power of the narrowband positioning reference signal (NPRS) . \n
			:param nprs_power: float Range: -80 to 10
		"""
		param = Conversions.decimal_value_to_str(nprs_power)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:POW {param}')

	def get_sein(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:SEIN \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.nprs.get_sein() \n
		Specifies the index of the physical ressource block (PRB) containing the NPRS. \n
			:return: nprs_seq_info: integer Range: 0 to 174
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:SEIN?')
		return Conversions.str_to_int(response)

	def set_sein(self, nprs_seq_info: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:SEIN \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_sein(nprs_seq_info = 1) \n
		Specifies the index of the physical ressource block (PRB) containing the NPRS. \n
			:param nprs_seq_info: integer Range: 0 to 174
		"""
		param = Conversions.decimal_value_to_str(nprs_seq_info)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:SEIN {param}')

	# noinspection PyTypeChecker
	def get_sfnm(self) -> enums.EutraNbiotNprsConfigbSfnumb:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:SFNM \n
		Snippet: value: enums.EutraNbiotNprsConfigbSfnumb = driver.source.bb.eutra.downlink.niot.nprs.get_sfnm() \n
		For NPRS Part B configuration, sets the number of consecutive DL subframes NNPRS within one NPRS positioning occasion. \n
			:return: nprs_sf_number: SFNM_10| SFNM_20| SFNM_40| SFNM_80| SFNM_160| SFNM_320| SFNM_640| SFNM_1280
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:SFNM?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotNprsConfigbSfnumb)

	def set_sfnm(self, nprs_sf_number: enums.EutraNbiotNprsConfigbSfnumb) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:SFNM \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_sfnm(nprs_sf_number = enums.EutraNbiotNprsConfigbSfnumb.SFNM_10) \n
		For NPRS Part B configuration, sets the number of consecutive DL subframes NNPRS within one NPRS positioning occasion. \n
			:param nprs_sf_number: SFNM_10| SFNM_20| SFNM_40| SFNM_80| SFNM_160| SFNM_320| SFNM_640| SFNM_1280
		"""
		param = Conversions.enum_scalar_to_str(nprs_sf_number, enums.EutraNbiotNprsConfigbSfnumb)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:SFNM {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:STATe \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.niot.nprs.get_state() \n
		Enables the NPRS transmission. \n
			:return: nprs_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, nprs_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:STATe \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_state(nprs_state = False) \n
		Enables the NPRS transmission. \n
			:param nprs_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(nprs_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:STATe {param}')

	# noinspection PyTypeChecker
	def get_sts_frame(self) -> enums.EutraNbiotNprsConfigbStartsf:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:STSFrame \n
		Snippet: value: enums.EutraNbiotNprsConfigbStartsf = driver.source.bb.eutra.downlink.niot.nprs.get_sts_frame() \n
		For NPRS Part B configuration, sets the subframe offset alphaNPRS. \n
			:return: nprs_start_sf: STSF0_8| STSF1_8| STSF2_8| STSF3_8| STSF4_8| STSF5_8| STSF6_8| STSF7_8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:STSFrame?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotNprsConfigbStartsf)

	def set_sts_frame(self, nprs_start_sf: enums.EutraNbiotNprsConfigbStartsf) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:STSFrame \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.set_sts_frame(nprs_start_sf = enums.EutraNbiotNprsConfigbStartsf.STSF0_8) \n
		For NPRS Part B configuration, sets the subframe offset alphaNPRS. \n
			:param nprs_start_sf: STSF0_8| STSF1_8| STSF2_8| STSF3_8| STSF4_8| STSF5_8| STSF6_8| STSF7_8
		"""
		param = Conversions.enum_scalar_to_str(nprs_start_sf, enums.EutraNbiotNprsConfigbStartsf)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:STSFrame {param}')

	def clone(self) -> 'NprsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NprsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhysBitsCls:
	"""PhysBits commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("physBits", core, parent)

	def get(self, subframeNull=repcap.SubframeNull.Default, userIx=repcap.UserIx.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:USER<CH>:PHYSbits \n
		Snippet: value: int = driver.source.bb.v5G.downlink.subf.user.physBits.get(subframeNull = repcap.SubframeNull.Default, userIx = repcap.UserIx.Default) \n
		No command help available \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: physical_bits: No help available"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:USER{userIx_cmd_val}:PHYSbits?')
		return Conversions.str_to_int(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LtKeyCls:
	"""LtKey commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ltKey", core, parent)

	def set(self, lt_key: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:LTKey \n
		Snippet: driver.source.bb.btooth.econfiguration.ltKey.set(lt_key = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1) \n
		Indicates the time the controller needs to receive the long-term key from the host. After this time, the controller is
		ready to enter into the last phase of encryption mode setup. \n
			:param lt_key: numeric
			:param bitcount: integer Range: 128 to 128
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('lt_key', lt_key, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:LTKey {param}'.rstrip())

	# noinspection PyTypeChecker
	class LtKeyStruct(StructBase):
		"""Response structure. Fields: \n
			- Lt_Key: List[str]: numeric
			- Bitcount: int: integer Range: 128 to 128"""
		__meta_args_list = [
			ArgStruct('Lt_Key', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lt_Key: List[str] = None
			self.Bitcount: int = None

	def get(self) -> LtKeyStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:LTKey \n
		Snippet: value: LtKeyStruct = driver.source.bb.btooth.econfiguration.ltKey.get() \n
		Indicates the time the controller needs to receive the long-term key from the host. After this time, the controller is
		ready to enter into the last phase of encryption mode setup. \n
			:return: structure: for return value, see the help for LtKeyStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:LTKey?', self.__class__.LtKeyStruct())
